Translate Toolkit — Translate Toolkit 2.4.0 documentation

# Translate Toolkit

Welcome to Translate Toolkit’s documentation. This documentation covers both user’s and programmer’s perspective.

## User’s Guide

This part has the user’s documentation for the tools included in the Translate Toolkit.

- Features
- Installation
- Converters
- Tools
- Scripts
- Use Cases
- Supported formats

## Developer’s Guide

If you are a developer interested in using the Translate Toolkit for building new tools, make sure to read through this part.

- Translate Styleguide
- Documentation
- Building
- Testing
- Command Line Functional Testing
- Contributing
- Translate Toolkit Developers Guide
- Making a Translate Toolkit Release
- Deprecation of Features

## Additional Notes

Changelog and legal information are included here.

- Release Notes
- History of the Translate Toolkit
- License

## API Reference

This part covers any function, class or method included within the Translate Toolkit that you can use to programatically build new localization tools.

- API
  - Module overview
  - Module list